@@ -69,7 +69,7 @@ gsf_output_istream_set_error (GsfOutput * output, HRESULT hr)
  * gsf_output_istream_new :
  * @stream   : IStream stream
  *
- * Returns a new output object or NULL.
+ * Returns: a new output object or %NULL.
  **/
 GsfOutput *
 gsf_output_istream_new (IStream * stream)
@@ -79,6 +79,8 @@ gsf_output_istream_new (IStream * stream)
 	g_return_val_if_fail (stream != NULL, NULL);
 
 	output = g_object_new (GSF_OUTPUT_ISTREAM_TYPE, NULL);
+	if (G_UNLIKELY (NULL == output)) return NULL;
+
 	output->stream = stream;
 	IStream_AddRef (output->stream);
 
